summary refs log tree commit diff
path: root/synapse/federation
diff options
context:
space:
mode:
authorRichard van der Hoff <richard@matrix.org>2020-04-20 17:42:27 +0100
committerRichard van der Hoff <richard@matrix.org>2020-04-20 17:42:27 +0100
commita46ff43319b55af68ef5858353481b2190c5bb61 (patch)
tree5815f1e7078b3336e24d400ffefac6ff08a8e9b0 /synapse/federation
parentFix indention in generated config file (#7300) (diff)
parentAlways send the user updates to their own device list (#7160) (diff)
downloadsynapse-a46ff43319b55af68ef5858353481b2190c5bb61.tar.xz
Merge branch 'release-v1.12.4' into develop
Diffstat (limited to 'synapse/federation')
-rw-r--r--synapse/federation/transport/client.py14
1 files changed, 11 insertions, 3 deletions
diff --git a/synapse/federation/transport/client.py b/synapse/federation/transport/client.py
index dc563538de..c35637a571 100644
--- a/synapse/federation/transport/client.py
+++ b/synapse/federation/transport/client.py
@@ -406,13 +406,19 @@ class TransportLayerClient(object):
               "device_keys": {
                 "<user_id>": {
                   "<device_id>": {...}
+              } }
+              "master_keys": {
+                "<user_id>": {...}
+              } }
+              "self_signing_keys": {
+                "<user_id>": {...}
             } } }
 
         Args:
             destination(str): The server to query.
             query_content(dict): The user ids to query.
         Returns:
             A dict containg the device keys.
         """
         path = _create_v1_path("/user/keys/query")
 
@@ -429,14 +435,16 @@ class TransportLayerClient(object):
         Response:
             {
               "stream_id": "...",
-              "devices": [ { ... } ]
+              "devices": [ { ... } ],
+              "master_key": { ... },
+              "self_signing_key: { ... }
             }
 
         Args:
             destination(str): The server to query.
             query_content(dict): The user ids to query.
         Returns:
             A dict containg the device keys.
         """
         path = _create_v1_path("/user/devices/%s", user_id)
@@ -406,13 +406,19 @@ class TransportLayerClient(object):
             query_content(dict): The user ids to query.
         Returns:
-            A dict containg the device keys.
+            A dict containing device and cross-signing keys.
         """
         path = _create_v1_path("/user/keys/query")
@@ -429,14 +435,16 @@ class TransportLayerClient(object):
             query_content(dict): The user ids to query.
         Returns:
-            A dict containg the device keys.
+            A dict containing device and cross-signing keys.
         """
         path = _create_v1_path("/user/devices/%s", user_id)